@@ -126,7 +126,7 @@ class OAuthManagerModule extends ReactContextBaseJavaModule {
   {
     try {
       final OAuthManagerModule self = this;
-      HashMap<String,Object> cfg = this.getConfiguration(providerName);
+      final HashMap<String,Object> cfg = this.getConfiguration(providerName);
       final String authVersion = (String) cfg.get("auth_version");
       Activity activity = mReactContext.getCurrentActivity();
       FragmentManager fragmentManager = activity.getFragmentManager();
@@ -136,37 +136,38 @@ class OAuthManagerModule extends ReactContextBaseJavaModule {
         public void onRequestTokenError(final Exception ex) {
           Log.e(TAG, "Exception with request token: " + ex.getMessage());
           _credentialsStore.delete(providerName);
+          _credentialsStore.commit();
         }
         public void onOAuth1AccessToken(final OAuth1AccessToken accessToken) {
           _credentialsStore.store(providerName, accessToken);
           _credentialsStore.commit();
 
-          WritableMap resp = self.accessTokenResponse(providerName, accessToken, authVersion);
+          WritableMap resp = self.accessTokenResponse(providerName, cfg, accessToken, authVersion);
           callback.invoke(null, resp);
         }
         public void onOAuth2AccessToken(final OAuth2AccessToken accessToken) {
           _credentialsStore.store(providerName, accessToken);
           _credentialsStore.commit();
 
-          WritableMap resp = self.accessTokenResponse(providerName, accessToken, authVersion);
+          WritableMap resp = self.accessTokenResponse(providerName, cfg, accessToken, authVersion);
           callback.invoke(null, resp);
         }
       };
 
       if (authVersion.equals("1.0")) {
         final OAuth10aService service = 
-          OAuthManagerProviders.getApiFor10aProvider(providerName, cfg, callbackUrl);
+          OAuthManagerProviders.getApiFor10aProvider(providerName, cfg, params, callbackUrl);
 
         OAuthManagerFragmentController ctrl =
-          new OAuthManagerFragmentController(fragmentManager, providerName, service, callbackUrl);
+          new OAuthManagerFragmentController(mReactContext, fragmentManager, providerName, service, callbackUrl);
 
         ctrl.requestAuth(cfg, listener);
       } else if (authVersion.equals("2.0")) {
         final OAuth20Service service =
-          OAuthManagerProviders.getApiFor20Provider(providerName, cfg, callbackUrl);
+          OAuthManagerProviders.getApiFor20Provider(providerName, cfg, params, callbackUrl);
         
         OAuthManagerFragmentController ctrl =
-          new OAuthManagerFragmentController(fragmentManager, providerName, service, callbackUrl);
+          new OAuthManagerFragmentController(mReactContext, fragmentManager, providerName, service, callbackUrl);
 
         ctrl.requestAuth(cfg, listener);
       } else {
@@ -240,13 +241,13 @@ class OAuthManagerModule extends ReactContextBaseJavaModule {
 
         if (authVersion.equals("1.0")) {
           final OAuth10aService service = 
-            OAuthManagerProviders.getApiFor10aProvider(providerName, cfg, null);
+            OAuthManagerProviders.getApiFor10aProvider(providerName, cfg, requestParams, null);
           OAuth1AccessToken token = _credentialsStore.get(providerName, OAuth1AccessToken.class);
           
           service.signRequest(token, request);
         } else if (authVersion.equals("2.0")) {
           final OAuth20Service service =
-            OAuthManagerProviders.getApiFor20Provider(providerName, cfg, null);
+            OAuthManagerProviders.getApiFor20Provider(providerName, cfg, requestParams, null);
           OAuth2AccessToken token = _credentialsStore.get(providerName, OAuth2AccessToken.class);
 
           service.signRequest(token, request);
@@ -290,52 +291,42 @@ class OAuthManagerModule extends ReactContextBaseJavaModule {
     @Nullable final ReadableMap params
     ) throws Exception {
     OAuthRequest request;
-    OAuthConfig config;
-    OAuth1AccessToken oa1token = null;
-    OAuth2AccessToken oa2token = null;
+    // OAuthConfig config;
 
     if (authVersion.equals("1.0")) {  
-      final OAuth10aService service = 
-          OAuthManagerProviders.getApiFor10aProvider(providerName, cfg, null);
-      oa1token = _credentialsStore.get(providerName, OAuth1AccessToken.class);
+      // final OAuth10aService service = 
+          // OAuthManagerProviders.getApiFor10aProvider(providerName, cfg, null, null);
+      OAuth1AccessToken oa1token = _credentialsStore.get(providerName, OAuth1AccessToken.class);
+      request = OAuthManagerProviders.getRequestForProvider(
+        providerName, 
+        httpVerb,
+        oa1token, 
+        url,
+        cfg,
+        params);
       
-      config = service.getConfig();
-      request = new OAuthRequest(httpVerb, url.toString(), config);
+      // config = service.getConfig();
+      // request = new OAuthRequest(httpVerb, url.toString(), config);
     } else if (authVersion.equals("2.0")) {
-      final OAuth20Service service =
-        OAuthManagerProviders.getApiFor20Provider(providerName, cfg, null);
-      oa2token = _credentialsStore.get(providerName, OAuth2AccessToken.class);
+      // final OAuth20Service service =
+        // OAuthManagerProviders.getApiFor20Provider(providerName, cfg, null, null);
+      // oa2token = _credentialsStore.get(providerName, OAuth2AccessToken.class);
 
-      config = service.getConfig();
-      request = new OAuthRequest(httpVerb, url.toString(), config);
+      OAuth2AccessToken oa2token = _credentialsStore.get(providerName, OAuth2AccessToken.class);
+      request = OAuthManagerProviders.getRequestForProvider(
+        providerName, 
+        httpVerb,
+        oa2token, 
+        url,
+        cfg,
+        params);
+      
+      // config = service.getConfig();
+      // request = new OAuthRequest(httpVerb, url.toString(), config);
     } else {
       Log.e(TAG, "Error in making request method");
       throw new Exception("Provider not handled yet");
     }
-          // Params
-    if (params != null && params.hasKey("params")) {
-      ReadableMapKeySetIterator iterator = params.keySetIterator();
-      while (iterator.hasNextKey()) {
-        String key = iterator.nextKey();
-        ReadableType readableType = params.getType(key);
-        switch(readableType) {
-          case String:
-            String val = params.getString(key);
-            // String escapedVal = Uri.encode(val);
-            if (val.equals("access_token")) {
-              if (oa1token != null) {
-                val = oa1token.toString();
-              } else if (oa2token != null) {
-                val = oa2token.toString();
-              }
-            }
-            request.addParameter(key, val);
-            break;
-          default:
-            throw new IllegalArgumentException("Could not read object with key: " + key);
-        }
-      }
-    }
 
     return request;
   }
@@ -364,7 +355,7 @@ class OAuthManagerModule extends ReactContextBaseJavaModule {
           throw new Exception("No token found");
         }
 
-        WritableMap resp = this.accessTokenResponse(providerName, token, authVersion);
+        WritableMap resp = this.accessTokenResponse(providerName, cfg, token, authVersion);
         onComplete.invoke(null, resp);
       } else if (authVersion.equals("2.0")) {
         OAuth2AccessToken token = _credentialsStore.get(providerName, OAuth2AccessToken.class);
@@ -372,7 +363,7 @@ class OAuthManagerModule extends ReactContextBaseJavaModule {
         if (token == null || token.equals("")) {
           throw new Exception("No token found");
         }
-        WritableMap resp = this.accessTokenResponse(providerName, token, authVersion);
+        WritableMap resp = this.accessTokenResponse(providerName, cfg, token, authVersion);
         onComplete.invoke(null, resp);
       } else {
 
@@ -420,19 +411,33 @@ class OAuthManagerModule extends ReactContextBaseJavaModule {
 
   private WritableMap accessTokenResponse(
     final String providerName,
+    final HashMap<String,Object> cfg,
     final OAuth1AccessToken accessToken,
     final String oauthVersion
   ) {
     WritableMap resp = Arguments.createMap();
     WritableMap response = Arguments.createMap();
 
+    Log.d(TAG, "Credential raw response: " + accessToken.getRawResponse());
+
     resp.putString("status", "ok");
+    resp.putBoolean("authorized", true);
     resp.putString("provider", providerName);
     response.putString("uuid", accessToken.getParameter("user_id"));
     
+    String tokenType = accessToken.getParameter("token_type");
+    if (tokenType == null) {
+      tokenType = "Bearer";
+    }
+
+    String consumerKey = (String) cfg.get("consumer_key");
+
     WritableMap credentials = Arguments.createMap();
-    credentials.putString("oauth_token", accessToken.getToken());
-    credentials.putString("oauth_secret", accessToken.getTokenSecret());
+    credentials.putString("accessToken", accessToken.getToken());
+    credentials.putString("type", tokenType);
+    // credentials.putString("scope", accessToken.getScope());
+    credentials.putString("consumerKey", consumerKey);
+
     response.putMap("credentials", credentials);
 
     resp.putMap("response", response);
@@ -442,6 +447,7 @@ class OAuthManagerModule extends ReactContextBaseJavaModule {
 
   private WritableMap accessTokenResponse(
     final String providerName,
+    final HashMap<String,Object> cfg,
     final OAuth2AccessToken accessToken,
     final String oauthVersion
   ) {
@@ -449,6 +455,7 @@ class OAuthManagerModule extends ReactContextBaseJavaModule {
     WritableMap response = Arguments.createMap();
 
     resp.putString("status", "ok");
+    resp.putBoolean("authorized", true);
     resp.putString("provider", providerName);
     try {
       response.putString("uuid", accessToken.getParameter("user_id"));
@@ -458,9 +465,28 @@ class OAuthManagerModule extends ReactContextBaseJavaModule {
     }
     
     WritableMap credentials = Arguments.createMap();
-    credentials.putString("oauth_token", accessToken.getAccessToken());
-    credentials.putString("oauth_secret", "");
-    credentials.putString("scope", accessToken.getScope());
+    Log.d(TAG, "Credential raw response: " + accessToken.getRawResponse());
+
+    credentials.putString("accessToken", accessToken.getAccessToken());
+    String authHeader;
+
+    String tokenType = accessToken.getParameter("token_type");
+    if (tokenType == null) {
+      tokenType = "Bearer";
+    }
+    
+    String scope = accessToken.getScope();
+    if (scope == null) {
+      scope = (String) cfg.get("scopes");
+    }
+
+    String clientID = (String) cfg.get("client_id");
+
+    authHeader = tokenType + " " + accessToken.getAccessToken();
+    credentials.putString("authorizationHeader", authHeader);
+    credentials.putString("type", tokenType);
+    credentials.putString("scopes", scope);
+    credentials.putString("clientID", clientID);
     response.putMap("credentials", credentials);
 
     resp.putMap("response", response);
