@@ -137,6 +137,8 @@ RCT_EXPORT_MODULE(OAuthManager);
     NSString *saveCallbackUrl = [self stringHost:callbackUrl];
     [arr addObject:saveCallbackUrl];
     _callbackUrls = [arr copy];
+
+    NSLog(@"Saved callback url: %@ in %@", saveCallbackUrl, _callbackUrls);
     
     // Convert objects of url type
     for (NSString *name in [config allKeys]) {
@@ -193,6 +195,7 @@ RCT_EXPORT_METHOD(configureProvider:
 
 #pragma mark OAuth
 
+// TODO: Remove opts
 RCT_EXPORT_METHOD(getSavedAccounts:(NSDictionary *) opts
                   callback:(RCTResponseSenderBlock) callback)
 {
@@ -214,6 +217,7 @@ RCT_EXPORT_METHOD(getSavedAccounts:(NSDictionary *) opts
                    }]);
 }
 
+// TODO: Remove opts
 RCT_EXPORT_METHOD(getSavedAccount:(NSString *)providerName
                   opts:(NSDictionary *) opts
                   callback:(RCTResponseSenderBlock)callback)
@@ -336,11 +340,14 @@ RCT_EXPORT_METHOD(authorize:(NSString *)providerName
     
     [manager addPending:client];
     _pendingAuthentication = YES;
+
+    NSLog(@"Calling authorizeWithUrl: %@ with callbackURL: %@\n %@", providerName, callbackUrl, cfg);
     
     [client authorizeWithUrl:providerName
                          url:callbackUrl
                          cfg:cfg
                    onSuccess:^(DCTAuthAccount *account) {
+                      NSLog(@"on success called with account: %@", account);
                        NSDictionary *accountResponse = [manager getAccountResponse:account cfg:cfg];
                        _pendingAuthentication = NO;
                        [manager removePending:client];
@@ -353,11 +360,12 @@ RCT_EXPORT_METHOD(authorize:(NSString *)providerName
                    } onError:^(NSError *error) {
                        NSLog(@"Error in authorizeWithUrl: %@", error);
                        _pendingAuthentication = NO;
-                       [manager removePending:client];
                        callback(@[@{
                                       @"status": @"error",
-                                      @"msg": [error localizedDescription]
+                                      @"msg": [error localizedDescription],
+                                      @"userInfo": error.userInfo
                                       }]);
+                       [manager removePending:client];
                    }];
 }
 
@@ -567,7 +575,13 @@ RCT_EXPORT_METHOD(makeRequest:(NSString *)providerName
         DCTOAuth2Credential *credential = account.credential;
         if (credential != nil) {
             
-            NSDictionary *cred = [self dictionaryForCredentialKeys: credential];
+            NSMutableDictionary *cred = [self dictionaryForCredentialKeys: credential];
+            
+            DCTOAuth2Account *oauth2Account = (DCTOAuth2Account *) account;
+            if (oauth2Account.scopes) {
+                [cred setObject:oauth2Account.scopes forKey:@"scopes"];
+            }
+            
             [accountResponse setObject:cred forKey:@"credentials"];
         }
     }
@@ -575,6 +589,7 @@ RCT_EXPORT_METHOD(makeRequest:(NSString *)providerName
     if (account.userInfo != nil) {
         [accountResponse setObject:[account userInfo] forKey:@"user_info"];
     }
+    
     return accountResponse;
 }
 
